#[non_exhaustive]pub enum LeanWorkerDeclarationVerificationStatus {
Accepted,
Rejected,
NotFound,
Ambiguous,
Timeout,
BudgetExceeded,
Unsupported,
NeedsBuild,
}Expand description
Verification policy result after diagnostics and declaration facts are collected.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Accepted
Rejected
NotFound
Ambiguous
Timeout
BudgetExceeded
Unsupported
NeedsBuild
The name did not resolve because the open environment is incomplete.
The enclosing
LeanWorkerDeclarationVerificationResult::MissingImports names the
unbuilt modules.