#[non_exhaustive]pub enum LeanWorkerModuleQueryOutcome {
Ok {
result: LeanWorkerModuleQueryResult,
imports: Vec<String>,
},
MissingImports {
result: LeanWorkerModuleQueryResult,
imports: Vec<String>,
missing: Vec<String>,
},
HeaderParseFailed {
diagnostics: LeanWorkerElabFailure,
},
Unsupported,
}Expand description
Outcome of LeanWorkerSession::process_module_query.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ok
Header parsed; every parsed import is present in the session’s open env; the query result is populated.
MissingImports
Header parsed but some imports name modules the session’s open env does not have. The body was still queried against the available env.
HeaderParseFailed
Lean.Parser.parseHeader reported error-severity messages; the body
was never elaborated.
Fields

diagnostics: LeanWorkerElabFailureUnsupported
The capability dylib does not export
lean_rs_host_process_module_query.