pub struct LeanWorkerDeclarationSearchPruning {
pub stage: String,
pub reason: String,
pub count: usize,
}Expand description
One broad fanout pruning record returned in search facts.
Fields
stage: Stringreason: Stringcount: usizeTrait Implementations
Sourceimpl Clone for LeanWorkerDeclarationSearchPruning
impl Clone for LeanWorkerDeclarationSearchPruning
Sourcefn clone(&self) -> LeanWorkerDeclarationSearchPruning
fn clone(&self) -> LeanWorkerDeclarationSearchPruning
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for LeanWorkerDeclarationSearchPruning
impl<'de> Deserialize<'de> for LeanWorkerDeclarationSearchPruning
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LeanWorkerDeclarationSearchPruning, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LeanWorkerDeclarationSearchPruning, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LeanWorkerDeclarationSearchPruning
Sourceimpl PartialEq for LeanWorkerDeclarationSearchPruning
impl PartialEq for LeanWorkerDeclarationSearchPruning
Sourcefn eq(&self, other: &LeanWorkerDeclarationSearchPruning) -> bool
fn eq(&self, other: &LeanWorkerDeclarationSearchPruning) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LeanWorkerDeclarationSearchPruning
impl Serialize for LeanWorkerDeclarationSearchPruning
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for LeanWorkerDeclarationSearchPruning