pub struct LeanWorkerProofPositionSummary {
pub index: u32,
pub tactic: LeanWorkerRenderedInfo,
}Expand description
Informational summary of the selected proof position. It is not an edit handle and cannot be fed back into proof-action requests.
Fields
index: u32tactic: LeanWorkerRenderedInfoTrait Implementations
Sourceimpl Clone for LeanWorkerProofPositionSummary
impl Clone for LeanWorkerProofPositionSummary
Sourcefn clone(&self) -> LeanWorkerProofPositionSummary
fn clone(&self) -> LeanWorkerProofPositionSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for LeanWorkerProofPositionSummary
impl<'de> Deserialize<'de> for LeanWorkerProofPositionSummary
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LeanWorkerProofPositionSummary, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LeanWorkerProofPositionSummary, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LeanWorkerProofPositionSummary
Sourceimpl PartialEq for LeanWorkerProofPositionSummary
impl PartialEq for LeanWorkerProofPositionSummary
Sourcefn eq(&self, other: &LeanWorkerProofPositionSummary) -> bool
fn eq(&self, other: &LeanWorkerProofPositionSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LeanWorkerProofPositionSummary
impl Serialize for LeanWorkerProofPositionSummary
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for LeanWorkerProofPositionSummary