LeanWorkerSessionConfig

Struct LeanWorkerSessionConfig 

pub struct LeanWorkerSessionConfig { /* private fields */ }
Configuration for opening one host session inside a worker child.

Implementations

Source

impl LeanWorkerSessionConfig

pub fn new( project_root: impl Into<PathBuf>, package: impl Into<String>, lib_name: impl Into<String>, imports: impl IntoIterator<Item = impl Into<String>>, ) -> Self

Create a session configuration for a Lake capability and import list.

pub fn manifest_backed( project_root: impl Into<PathBuf>, package: impl Into<String>, lib_name: impl Into<String>, manifest_path: impl Into<PathBuf>, imports: impl IntoIterator<Item = impl Into<String>>, ) -> Self

Create a manifest-backed session configuration for a Lake capability.

pub fn shims_only( project_root: impl Into<PathBuf>, imports: impl IntoIterator<Item = impl Into<String>>, ) -> Self

Create a session configuration backed only by the bundled host shims.

pub fn with_import_profile( self, profile: LeanWorkerSessionImportProfile, ) -> Self

Select the full-session import profile for this worker session.

pub fn import_profile(&self) -> LeanWorkerSessionImportProfile

Return the full-session import profile used when opening this config.

pub fn with_imports( &self, imports: impl IntoIterator<Item = impl Into<String>>, ) -> Self

Return a copy of this config with a different import list, preserving the loading mode and import profile.