pub struct LeanWorkerSessionConfig { /* private fields */ }Expand description
Configuration for opening one host session inside a worker child.
Implementations
Sourceimpl LeanWorkerSessionConfig
impl LeanWorkerSessionConfig
Sourcepub fn new(
project_root: impl Into<PathBuf>,
package: impl Into<String>,
lib_name: impl Into<String>,
imports: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn new( project_root: impl Into<PathBuf>, package: impl Into<String>, lib_name: impl Into<String>, imports: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Create a session configuration for a Lake capability and import list.
Sourcepub fn manifest_backed(
project_root: impl Into<PathBuf>,
package: impl Into<String>,
lib_name: impl Into<String>,
manifest_path: impl Into<PathBuf>,
imports: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn manifest_backed( project_root: impl Into<PathBuf>, package: impl Into<String>, lib_name: impl Into<String>, manifest_path: impl Into<PathBuf>, imports: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Create a manifest-backed session configuration for a Lake capability.
Sourcepub fn shims_only(
project_root: impl Into<PathBuf>,
imports: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn shims_only( project_root: impl Into<PathBuf>, imports: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Create a session configuration backed only by the bundled host shims.
Sourcepub fn with_import_profile(
self,
profile: LeanWorkerSessionImportProfile,
) -> Self
pub fn with_import_profile( self, profile: LeanWorkerSessionImportProfile, ) -> Self
Select the full-session import profile for this worker session.
Sourcepub fn import_profile(&self) -> LeanWorkerSessionImportProfile
pub fn import_profile(&self) -> LeanWorkerSessionImportProfile
Return the full-session import profile used when opening this config.
Sourcepub fn with_imports(
&self,
imports: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_imports( &self, imports: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Return a copy of this config with a different import list, preserving the loading mode and import profile.